from __future__ import annotations

from typing import TYPE_CHECKING

import discord
from loguru import logger

from discord_reminder_bot.markdown_utils import generate_reminder_summary

if TYPE_CHECKING:
    from apscheduler.job import Job
    from apscheduler.schedulers.asyncio import AsyncIOScheduler


async def list_reminder_job(interaction: discord.Interaction, scheduler: AsyncIOScheduler) -> None:
    """List all reminder jobs in the scheduler.

    Args:
        interaction (discord.Interaction): The interaction object for the command.
        scheduler (AsyncIOScheduler): The scheduler to list the jobs from.
    """
    user: discord.User | discord.Member = interaction.user
    if not isinstance(user, discord.Member):
        await interaction.followup.send(content="This command can only be used in a server.", ephemeral=True)
        return

    channel = interaction.channel
    if not isinstance(channel, discord.TextChannel):
        await interaction.followup.send(content="This command can only be used in a text channel.", ephemeral=True)
        return

    logger.info(f"Listing reminders for {user} ({user.id}) in {interaction.channel}")
    logger.info(f"Arguments: {locals()}")

    jobs: list[Job] = scheduler.get_jobs()
    if not jobs:
        await interaction.followup.send(content="No scheduled jobs found in the database.", ephemeral=True)
        return

    guild: discord.Guild | None = interaction.guild
    if not guild:
        await interaction.followup.send(content="Failed to get guild.", ephemeral=True)
        return

    message: discord.InteractionMessage = await interaction.original_response()

    job_summary: list[str] = generate_reminder_summary(ctx=interaction, bot=interaction.client, scheduler=scheduler)

    for i, msg in enumerate(job_summary):
        if i == 0:
            await message.edit(content=msg)
        else:
            await interaction.followup.send(content=msg)
